bread.contrib.activities.examples package
=========================================

.. automodule:: bread.contrib.activities.examples
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

bread.contrib.activities.examples.deactivate\_user module
---------------------------------------------------------

.. automodule:: bread.contrib.activities.examples.deactivate_user
   :members:
   :undoc-members:
   :show-inheritance:
